@@ -20,8 +20,8 @@ from magicapi import g
 from magicapi.Decorators.helpers import async_safe
 
 
-def run_in_background(f):
-    router_path = f"/run_in_background/{f.__name__}"
+def run_in_background_no_dynamo(f):
+    router_path = f"/run_in_background_no_dynamo/{f.__name__}"
     new_r = APIRouter()
 
     @new_r.post(router_path, tags=["background_tasks"], include_in_schema=False)
@@ -56,8 +56,8 @@ def run_in_background(f):
     return wrapper
 
 
-def run_in_background_dynamo(f):
-    router_path = f"/run_in_background_dynamo/{f.__name__}"
+def run_in_background(f):
+    router_path = f"/run_in_background/{f.__name__}"
     new_r = APIRouter()
 
     @new_r.post(router_path, tags=["background_tasks_dynamo"], include_in_schema=False)
