@@ -8,6 +8,18 @@ from typing import Callable
 from magicapi.Models.Call import make_call_from_request_and_response
 from magicapi.Models.task_executor import save_tasks
 
+import os
+import sentry_sdk
+
+sentry_sdk.init(
+    os.getenv("SENTRY_DSN"),
+    # Set traces_sample_rate to 1.0 to capture 100%
+    # of transactions for performance monitoring.
+    # We recommend adjusting this value in production.
+    traces_sample_rate=1.0,
+)
+from sentry_sdk import capture_exception
+
 
 class MagicCallLogger(APIRoute):
     def get_route_handler(self) -> Callable:
@@ -20,6 +32,10 @@ class MagicCallLogger(APIRoute):
             try:
                 response: Response = await original_route_handler(request)
             except Exception as e:
+                capture_exception(e)
+                if "aws.context" in request.scope:
+                    context = request.scope["aws.context"]
+                    context.serverless_sdk.capture_exception(e)
                 print("Error in call route", e.__dict__)
                 error = e
             time_done = datetime.utcnow()
@@ -35,7 +51,7 @@ class MagicCallLogger(APIRoute):
                 try:
                     save_tasks()
                 except Exception as save_task_error:
-                    print('[ERROR] save task error', save_task_error)
+                    print("[ERROR] save task error", save_task_error)
                 raise error
             return response
 
