@@ -109,7 +109,12 @@ def use_route_names_as_operation_ids(app: FastAPI) -> None:
             route.operation_id = route.name
 
 
+from raven import Client  # Offical `raven` module
+from raven_python_lambda import RavenLambdaWrapper
+
+
 def create_handler(app):
+    @RavenLambdaWrapper()
     def handler(event, context):
         """Handler to give to lambda... which wraps FastAPI"""
         if event.get("source") in ["aws.events", "serverless-plugin-warmup"]:
